OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan inte skriva till \"config\" katalogen!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Men, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den.",
    "See %s" : "Se %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Appen %1$s finns inte eller har en icke-kompatibel version med denna server. Kontrollera appkatalogen.",
    "Sample configuration detected" : "Exempel-konfiguration detekterad",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har upptäckts att provkonfigurationen har kopierats. Detta kan bryta din installation och stöds inte. Läs dokumentationen innan du utför ändringar på config.php",
    "The page could not be found on the server." : "Sidan kunde inte hittas på servern.",
    "%s email verification" : "%s e-postverifikation",
    "Email verification" : "E-postverifikation",
    "Click the following button to confirm your email." : "Klicka på följande knapp för att verifiera din e-postadress.",
    "Click the following link to confirm your email." : "Klicka på följande länk för att verifiera din e-postadress.",
    "Confirm your email" : "Verifiera din e-postadress",
    "Other activities" : "Andra aktiviteter",
    "%1$s and %2$s" : "%1$s och %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s och %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s och %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s och %5$s",
    "Education Edition" : "Utbildningspaket",
    "Enterprise bundle" : "Företagspaketet",
    "Groupware bundle" : "Gruppvarupaket",
    "Hub bundle" : "Hub-paket",
    "Public sector bundle" : "Paket för offentlig sektor",
    "Social sharing bundle" : "Kommunikationspaket",
    "PHP %s or higher is required." : "PHP %s eller högre krävs.",
    "PHP with a version lower than %s is required." : "PHP med version lägre än %s krävs.",
    "%sbit or higher PHP required." : "%sbit eller nyare PHP-version krävs.",
    "The following architectures are supported: %s" : "Följande arkitekturer stöds: %s",
    "The following databases are supported: %s" : "Följande databaser stöds: %s",
    "The command line tool %s could not be found" : "Kommandoradsverktyget %s hittades inte.",
    "The library %s is not available." : "Biblioteket %s är inte tillgängligt.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Bibliotek %1$s med en högre version än %2$s krävs - tillgänglig version %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Bibliotek %1$s med en lägre version än %2$s krävs - tillgänglig version %3$s.",
    "The following platforms are supported: %s" : "Följande plattformar stöds: %s",
    "Server version %s or higher is required." : "Serverversion %s eller nyare krävs.",
    "Server version %s or lower is required." : "Serverversion %s eller äldre krävs.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Inloggat konto måste vara en admin, underadministratör eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
    "Logged in account must be an admin or sub admin" : "Inloggat konto måste vara en admin eller underadministratör",
    "Logged in account must be an admin" : "Inloggat konto måste vara admin",
    "Wiping of device %s has started" : "Rensning av enhet %s har startat",
    "Wiping of device »%s« has started" : "Rensning av enhet »%s« har startat",
    "»%s« started remote wipe" : "»%s« startade fjärrensning",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Enhet eller applikation »%s« har startat fjärrensning. Du kommer att få ett nytt mail när processen är klar",
    "Wiping of device %s has finished" : "Rensning av enhet %s har slutförts",
    "Wiping of device »%s« has finished" : "Rensning av enhet »%s« har slutförts",
    "»%s« finished remote wipe" : "»%s« slutförde fjärrensning",
    "Device or application »%s« has finished the remote wipe process." : "Enhet eller applikation »%s« har slutfört fjärrensning.",
    "Remote wipe started" : "Fjärrensning startad",
    "A remote wipe was started on device %s" : "Fjärrensning startades på enhet %s",
    "Remote wipe finished" : "Fjärrensning klar",
    "The remote wipe on %s has finished" : "Fjärrensning av enhet %s har slutörts",
    "Authentication" : "Autentisering",
    "Unknown filetype" : "Okänd filtyp",
    "Invalid image" : "Ogiltig bild",
    "Avatar image is not square" : "Profilbilden är inte fyrkantig",
    "Files" : "Filer",
    "View profile" : "Visa profil",
    "Local time: %s" : "Lokal tid: %s",
    "today" : "idag",
    "tomorrow" : "imorgon",
    "yesterday" : "igår",
    "_in %n day_::_in %n days_" : ["om %n dag","om %n dagar"],
    "_%n day ago_::_%n days ago_" : ["%n dag sedan","%n dagar sedan"],
    "next month" : "nästa månad",
    "last month" : "förra månaden",
    "_in %n month_::_in %n months_" : ["om %n månad","om %n månader"],
    "_%n month ago_::_%n months ago_" : ["%n månad sedan","%n månader sedan"],
    "next year" : "nästa år",
    "last year" : "förra året",
    "_in %n year_::_in %n years_" : ["om %n år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år sedan","%n år sedan"],
    "_in %n hour_::_in %n hours_" : ["om %n timme","om %n timmar"],
    "_%n hour ago_::_%n hours ago_" : ["%n timme sedan","%n timmar sedan"],
    "_in %n minute_::_in %n minutes_" : ["om %n minut","om %n minuter"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut sedan","%n minuter sedan"],
    "in a few seconds" : "om några sekunder",
    "seconds ago" : "sekunder sedan",
    "Empty file" : "Tom fil",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulen med ID: %s finns inte. Aktivera den i appinställningar eller kontakta din administratör.",
    "File already exists" : "Filen existerar redan",
    "Invalid path" : "Ogiltig sökväg",
    "Failed to create file from template" : "Kunde skapa fil från mall",
    "Templates" : "Mallar",
    "File name is a reserved word" : "Filnamnet är ett reserverat ord",
    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
    "File name is too long" : "Filnamnet är för långt",
    "Dot files are not allowed" : "Dot-filer är inte tillåtna",
    "Empty filename is not allowed" : "Tomma filnamn är inte tillåtna",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan inte installeras eftersom appinfo-filen inte kan läsas.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
    "__language_name__" : "Svenska",
    "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt e-postmeddelande, du kan därmed inte svara på det.",
    "Appearance and accessibility" : "Utseende och tillgänglighet",
    "Apps" : "Appar",
    "Personal settings" : "Personlig information",
    "Administration settings" : "Administration",
    "Settings" : "Inställningar",
    "Log out" : "Logga ut",
    "Users" : "Användare",
    "Email" : "E-post",
    "Mail %s" : "Skicka e-post %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Visa %s på fediverse",
    "Phone" : "Telefon",
    "Call %s" : "Ring %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Se %s på Twitter",
    "Website" : "Hemsida",
    "Visit %s" : "Besök %s",
    "Address" : "Adress",
    "Profile picture" : "Profilbild",
    "About" : "Om",
    "Display name" : "Visningsnamn",
    "Headline" : "Rubrik",
    "Organisation" : "Organisation",
    "Role" : "Roll",
    "Unknown account" : "Okänt konto",
    "Additional settings" : "Övriga inställningar",
    "Enter the database Login and name for %s" : "Ange databas-inloggning och namn för %s",
    "Enter the database Login for %s" : "Ange databas-inloggning för %s",
    "Enter the database name for %s" : "Ange databasnamn för %s",
    "You cannot use dots in the database name %s" : "Du kan inte använda punkter i databasnamnet %s",
    "MySQL Login and/or password not valid" : "MySQL-inloggning och/eller lösenord är felaktigt",
    "You need to enter details of an existing account." : "Du måste ange inloggningsuppgifter av ett aktuellt konto.",
    "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
    "Oracle Login and/or password not valid" : "Oracle-inloggning och/eller lösenord är felaktigt",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL-inloggning och/eller lösenord är felaktigt",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
    "Set an admin Login." : "Ange en admin-inloggning.",
    "Set an admin password." : "Ange ett administratörslösenord.",
    "Cannot create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delningsgränssnittet %s hittades inte",
    "Sharing backend for %s not found" : "Delningsgränssnittet för %s hittades inte",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delade »%2$s« med dig och vill lägga till:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delade »%2$s« med dig och vill lägga till",
    "»%s« added a note to a file shared with you" : "»%s« la till en kommentar till en fil delad med dig",
    "Open »%s«" : "Öppna »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Du tillåts inte att dela %s",
    "Cannot increase permissions of %s" : "Kan inte höja behörigheter av %s",
    "Files cannot be shared with delete permissions" : "Filer kan inte delas med rättighet att radera",
    "Files cannot be shared with create permissions" : "Filer kan inte delas med rättighet att skapa",
    "Expiration date is in the past" : "Utgångsdatum är i det förflutna",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan inte sätta ett utgångsdatum längre fram än %n dag","Kan inte sätta ett utgångsdatum längre fram än %n dagar"],
    "Sharing is only allowed with group members" : "Delning är endast tillåten med gruppmedlemmar",
    "Sharing %s failed, because this item is already shared with the account %s" : "Delning av %s misslyckades, eftersom det här objektet redan delas med kontot %s",
    "%1$s shared »%2$s« with you" : "%1$s delade »%2$s« med dig",
    "%1$s shared »%2$s« with you." : "%1$s delade »%2$s« med dig.",
    "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
    "The requested share does not exist anymore" : "Den begärda delningen finns inte mer",
    "The requested share comes from a disabled user" : "Den begärda delningen kommer från en inaktiverad användare",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Användaren skapades inte eftersom användargränsen har nåtts. Kontrollera dina aviseringar för att läsa mer.",
    "Could not find category \"%s\"" : "Kunde inte hitta kategorin \"%s\"",
    "Sunday" : "Söndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sun." : "Sön.",
    "Mon." : "Mån.",
    "Tue." : "Tis.",
    "Wed." : "Ons.",
    "Thu." : "Tors.",
    "Fri." : "Fre.",
    "Sat." : "Lör.",
    "Su" : "Sö",
    "Mo" : "Må",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lö",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Mars",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Augusti",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Ett giltigt lösenord måste anges",
    "The Login is already being used" : "Inloggningen används redan",
    "Could not create account" : "Kunde inte skapa konto",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i en inloggning: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
    "A valid Login must be provided" : "En giltig inloggning måste anges",
    "Login contains whitespace at the beginning or at the end" : "Inloggningen innehåller blanksteg i början eller slutet",
    "Login must not consist of dots only" : "Inloggningen får inte innehålla enbart punkter",
    "Login is invalid because files already exist for this user" : "Inloggningen är ogiltigt eftersom det redan finns filer för den här användaren",
    "Account disabled" : "Konto inaktiverat",
    "Login canceled by app" : "Inloggningen avbruten av appen",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
    "a safe home for all your data" : "ett säkert hem för all din data",
    "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
    "Cannot download file" : "Kan inte ladda ner fil",
    "Application is not enabled" : "Applikationen är inte aktiverad",
    "Authentication error" : "Fel vid autentisering",
    "Token expired. Please reload page." : "Token har löpt ut. Uppdatera sidan.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Inga databasdrivrutiner (sqlite, mysql, eller postgresql) installerade.",
    "Cannot write into \"config\" directory." : "Kan inte skriva i \"config\"-katalogen.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen. Se %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den. Se %s",
    "Cannot write into \"apps\" directory." : "Kan inte skriva till \"apps\"-katalogen.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till \"apps\"-katalogen eller stänga av appbutiken i konfigurationsfilen.",
    "Cannot create \"data\" directory." : "Kan inte skapa \"data\"-katalog.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Behörigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
    "Your data directory is not writable." : "Din datakatalog är inte skrivbar.",
    "Setting locale to %s failed." : "Inställning av språk till %s misslyckades.",
    "Please install one of these locales on your system and restart your web server." : "Installera en av dessa locales på ditt system och starta om din webbserver.",
    "PHP module %s not installed." : "PHP-modulen %s är inte installerad.",
    "Please ask your server administrator to install the module." : "Be serveradministratören att installera modulen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-inställning \"%s\" är inte inställd på \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Att ändra denna inställning i php.ini kommer göra så att Nextcloud fungerar igen",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> är satt till <code>%s</code> istället för förväntade värdet <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : " För att åtgärda detta problemet, sätt<code>mbstring.func_overload</code> till <code>0</code> i din php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP är tydligen inställt för att tömma \"inline doc blocks\". Detta kommer att göra flera kärnprogram otillgängliga.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
    "Please ask your server administrator to restart the web server." : "Be din serveradministratör att starta om webbservern.",
    "The required %s config variable is not configured in the config.php file." : "Den nödvändiga konfigurationsvariabeln %s är inte konfigurerad i filen config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Be din serveradministratör att kontrollera Nextcloud-konfigurationen.",
    "Your data directory is readable by other people." : "Din datakatalog kan läsas av andra användare.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
    "Your data directory must be an absolute path." : "Din datakatalog måste vara en absolut sökväg.",
    "Check the value of \"datadirectory\" in your configuration." : "Kontrollera värdet på \"datadirectory\" i din konfiguration.",
    "Your data directory is invalid." : "Din datakatalog är ogiltig.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för din data.",
    "Action \"%s\" not supported or implemented." : "Åtgärd \"%s\" stöds inte eller är inte implementerad.",
    "Authentication failed, wrong token or provider ID given" : "Autentisering misslyckades, felaktig token eller leverantörs-ID",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametrar saknas för att slutföra förfrågan. Saknade parametrar: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" används redan av moln - federationsleverantör \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Moln - federationsleverantör med ID: \"%s\" finns inte.",
    "Could not obtain lock type %d on \"%s\"." : "Kunde inte hämta låstyp %d på \"%s\".",
    "Storage unauthorized. %s" : "Lagring obehörig. %s",
    "Storage incomplete configuration. %s" : "Lagringsutrymme felaktigt inställt. %s",
    "Storage connection error. %s" : "Lagringsutrymme lyckas inte ansluta. %s",
    "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
    "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
    "Generate headline" : "Skapa rubrik",
    "Generates a possible headline for a text." : "Genererar en möjlig rubrik för en text.",
    "Summarize" : "Sammanfatta",
    "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
    "Extract topics" : "Extrahera ämnen",
    "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Inloggad användare måste vara en admin, sub-admin eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
    "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
    "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
    "Help" : "Hjälp",
    "Unknown user" : "Okänd användare",
    "Enter the database username and name for %s" : "Ange databasanvändarnamn och lösenord för %s",
    "Enter the database username for %s" : "Ange databasanvändare för %s",
    "MySQL username and/or password not valid" : "MySQL-användarnamn och/eller lösenord är felaktigt",
    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
    "Set an admin username." : "Ange ett användarnamn för administratören.",
    "Sharing %s failed, because this item is already shared with user %s" : "Delning av %s misslyckades eftersom detta redan är delat med användaren %s",
    "The username is already being used" : "Användarnamnet används redan",
    "Could not create user" : "Kunde inte skapa användare",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i ett användarnamn: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
    "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
    "Username must not consist of dots only" : "Användarnamnet får inte innehålla enbart punkter",
    "Username is invalid because files already exist for this user" : "Användarnamnet är ogiltigt eftersom det redan finns filer för den här användaren",
    "User disabled" : "Användare inaktiverad",
    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 krävs.",
    "Please upgrade your database version." : "Uppgradera din databasversion.",
    "Your data directory is readable by other users." : "Din datakatalog kan läsas av andra användare.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare."
},
"nplurals=2; plural=(n != 1);");
